---
name: Bug report
about: Create a report to help us improve

---

**Describe the bug**
A clear and concise description of what the bug is.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Actual behavior**
<!--- Paste verbatim command output between quotes -->
```paste below

```
**Example Playbook**
<!--- Paste an example playbook that can be used to reproduce the problem between quotes -->
```paste below

```

**OS / Environment**
<!--- Provide all relevant information below, e.g. target OS versions, network device firmware, etc. -->

**Ansible Version**
<!--- Paste verbatim output from "ansible --version" between quotes -->
```paste below

```

**Role Version**
<!--- Paste version of the role between quotes -->
```paste below

```

**Additional context**
Add any other context about the problem here.
